@@ -10,7 +10,7 @@ from itertools import chain
 from sys import intern
 
 from snakeoil import chksum, data_source, fileutils, klass
-from snakeoil.demandload import demand_compile_regexp
+from snakeoil.delayed import regexp
 from snakeoil.mappings import OrderedFrozenSet
 
 from .. import fetch
@@ -20,17 +20,14 @@ from ..package import errors as metadata_errors
 from ..package import metadata
 from ..package.base import DynamicGetattrSetter
 from ..restrictions import boolean, values
-from . import conditionals
+from . import conditionals, processor
 from . import errors as ebuild_errors
-from . import processor
 from .atom import atom
 from .eapi import get_eapi
 from .misc import sort_keywords
 
-demand_compile_regexp(
-    "_EAPI_regex", r"^EAPI=(['\"]?)(?P<EAPI>[A-Za-z0-9+_.-]*)\1[\t ]*(?:#.*)?"
-)
-demand_compile_regexp("_EAPI_str_regex", r"^EAPI=(['\"]?)(?P<EAPI>.*)\1")
+_EAPI_regex = regexp(r"^EAPI=(['\"]?)(?P<EAPI>[A-Za-z0-9+_.-]*)\1[\t ]*(?:#.*)?")
+_EAPI_str_regex = regexp(r"^EAPI=(['\"]?)(?P<EAPI>.*)\1")
 
 
 class base(metadata.package):
@@ -302,7 +299,7 @@ class base(metadata.package):
             error = str(e) if eapi else f"{e}: {eapi_str!r}"
             raise metadata_errors.MetadataException(self, "eapi", error)
 
-    is_supported = klass.alias_attr("eapi.is_supported")
+    supported = klass.alias_attr("eapi.supported")
     tracked_attributes = klass.alias_attr("eapi.tracked_attributes")
 
     @DynamicGetattrSetter.register
@@ -517,7 +514,7 @@ class package_factory(metadata.factory):
 
     def _update_metadata(self, pkg, ebp=None):
         parsed_eapi = pkg.eapi
-        if not parsed_eapi.is_supported:
+        if not parsed_eapi.supported:
             return {"EAPI": str(parsed_eapi)}
 
         with processor.reuse_or_request(ebp) as my_proc:
