@@ -3,12 +3,11 @@ import subprocess
 import textwrap
 from collections.abc import MutableSet
 from datetime import datetime
-
-from snakeoil import klass
-from snakeoil.fileutils import touch
-from snakeoil.osutils import pjoin
+from os.path import join as pjoin
 
 import pytest
+from snakeoil import klass
+from snakeoil.fileutils import touch
 
 
 class GitRepo:
@@ -54,7 +53,7 @@ class GitRepo:
             **kwargs,
         )
 
-    def log(self, args):
+    def log(self, args: list[str]):
         """Run ``git log`` with given args and return a list of outputted lines."""
         p = self.run(["git", "log"] + args, stdout=subprocess.PIPE)
         return p.stdout.strip().splitlines()
@@ -75,7 +74,7 @@ class GitRepo:
     def __str__(self):
         return self.path
 
-    def commit(self, msg, signoff=False):
+    def commit(self, msg: str | list[str], signoff=False):
         """Make a commit to the repo."""
         if isinstance(msg, str):
             msg = msg.splitlines()
@@ -213,7 +212,7 @@ class EbuildRepo:
     def sync(self):
         """Forcibly create underlying repo object avoiding cache usage."""
         # avoid issues loading modules that set signal handlers
-        from pkgcore.ebuild import repo_objs, repository
+        from ..ebuild import repo_objs, repository
 
         repo_config = repo_objs.RepoConfig(
             location=self.path, disable_inst_caching=True
@@ -237,10 +236,10 @@ class EbuildRepo:
                 with open(pjoin(self.path, "profiles", p.path, "eapi"), "w") as f:
                     f.write(f"{p.eapi}\n")
 
-    def create_ebuild(self, cpvstr, data=None, **kwargs):
-        from pkgcore.ebuild import cpv as cpv_mod
+    def create_ebuild(self, cpvstr: str, data=None, **kwargs):
+        from ..ebuild.cpv import VersionedCPV
 
-        cpv = cpv_mod.VersionedCPV(cpvstr)
+        cpv = VersionedCPV(cpvstr)
         self._repo.notify_add_package(cpv)
         ebuild_dir = pjoin(self.path, cpv.category, cpv.package)
         os.makedirs(ebuild_dir, exist_ok=True)
